--============================================================================
-- Design units : detectClock
-- File name    : TB_detectClock.vhd
--
-- Description  : Testbench for detectClock.vhd
--
--
-- Uses         : None
--
-- Author       : Klaus Ruzicka, Zurich, Switzerland
--
--============================================================================
-- Revision list
-- Version  Author  Date      Changes
--
-- 1.0      Rkl     06/01/99  New design
--============================================================================
library IEEE;
use IEEE.std_logic_1164.all;

entity test_detectClock is
end test_detectClock;

architecture behav of test_detectClock is
component detClk1
  port( clk	: in  std_logic;	-- target clock domain
	D	: in  std_logic;	-- asynchronous input
	Q	: out std_logic);	-- synchronous output
end component;
component detClk2
  port( clk	: in  std_logic;	-- target clock domain
	D	: in  std_logic;	-- asynchronous input
	Q	: out std_logic);	-- synchronous output
end component;
component selClk
  port( clk	  : in  std_logic;	-- target clock domain
	clkP,clkR : in  std_logic;	-- asynchronous clock signals
        sel       : out std_logic);	-- which clock? 0=prim, 1=red
end component;

signal clk	: std_logic := '0';	-- board clock

signal clk2     : std_logic := '0';	-- regular RX clock
signal clk3     : std_logic := 'X';	-- exceptions to RX clock
signal D1,D2	: std_logic := '0';	-- used RX clock

signal Q1,Q2,w	: std_logic;		-- results

begin
 UU1: detClk1 port map (
    Clk => Clk,
    D   => D1,
    Q	=> Q1);
 UU2: detClk2 port map (
    Clk => Clk,
    D   => D2,
    Q	=> Q2);
 UUT: selClk port map (
    Clk  => Clk,
    clkP => D1,
    clkR => D2,
    sel	 => w);
 

  Clk <= not(Clk)  after 100 ns;
  clk2<= not(clk2) after  90 ns;

  genSpecialClk: process
  begin
    wait for 710 ns; 
    clk3 <= '0';
    wait for 2000 ns; 
    clk3 <= 'X';
    wait for 610 ns; 
    clk3 <= '1';
    wait for 2000 ns; 
    clk3 <= 'X';
    wait for 2000 ns; 
    clk3 <= '1';
    wait for 417 ns;
    clk3 <= '0';
    wait for 10 ns;
    clk3 <= '1';
    wait for 417 ns;
    clk3 <= '0';
    wait for 10 ns;
    clk3 <= '1';
    wait for 417 ns;
    clk3 <= '0';
    wait for 10 ns;
    clk3 <= '1';
    wait for 417 ns;
    clk3 <= '0';
    wait for 10 ns;
    clk3 <= '1';
    wait for 417 ns;
    clk3 <= '0';
    wait for 10 ns;
    clk3 <= '1';
    wait for 417 ns;
    clk3 <= 'X';
    wait;
  end process; -- testbench

  stimulus:process(clk2,clk3)
  begin
    if clk3='X' then
      d1 <= clk2;
    else 
      d1 <= clk3;
    end if;
  end process;
  D2 <= D1'delayed(2 us);

end behav; -- test_pSync

-- ===========================================================================
-- end of file
-- ===========================================================================
